@@ -119,9 +119,11 @@ class estimator():
                 self.version = 1
             #self.model_path = 'trained_states/{}d/{}d_{}.ckpt'.format(self.dim, self.dim, self.num_point)
             model_resources = files('deep_density_estimation')
-            self.model_path = as_file(model_resources / 'trained_states' / '{}d'.format(self.dim) / '{}d_{}.ckpt'.format(self.dim, self.num_point))
+            model_path_manager = as_file(model_resources / 'trained_states' / '{}d'.format(self.dim) / '{}d_{}.ckpt'.format(self.dim, self.num_point))
+            with model_path_manager as mpm:
+                self.model_path = str(mpm)
             print(self.model_path)
-            #assert os.path.exists(self.model_path+'.index'), 'could not find model {}'.format(self.model_path)
+            assert os.path.exists(self.model_path+'.index'), 'could not find model {}'.format(self.model_path)
         
         self.batch_size = batch_size
         
